@@ -18,6 +18,7 @@ contribute code, please `raise an issue on GitHub
 """
 import multiprocessing
 import atexit
+from contextlib import suppress
 
 
 from numcodecs.version import version as __version__
@@ -32,13 +33,11 @@ register_codec(GZip)
 from numcodecs.bz2 import BZ2
 register_codec(BZ2)
 
-try:
+with suppress(ImportError):
     from numcodecs.lzma import LZMA
     register_codec(LZMA)
-except ImportError:  # pragma: no cover
-    pass
 
-try:
+with suppress(ImportError):
     from numcodecs import blosc
     from numcodecs.blosc import Blosc
     register_codec(Blosc)
@@ -50,28 +49,20 @@ try:
     blosc.init()
     blosc.set_nthreads(min(8, ncores))
     atexit.register(blosc.destroy)
-except ImportError:  # pragma: no cover
-    pass
 
-try:
+with suppress(ImportError):
     from numcodecs import zstd
     from numcodecs.zstd import Zstd
     register_codec(Zstd)
-except ImportError:  # pragma: no cover
-    pass
 
-try:
+with suppress(ImportError):
     from numcodecs import lz4
     from numcodecs.lz4 import LZ4
     register_codec(LZ4)
-except ImportError:  # pragma: no cover
-    pass
 
-try:
+with suppress(ImportError):
     from numcodecs.zfpy import ZFPY
     register_codec(ZFPY)
-except ImportError:  # pragma: no cover
-    pass
 
 from numcodecs.astype import AsType
 register_codec(AsType)
@@ -100,11 +91,12 @@ register_codec(Base64)
 from numcodecs.shuffle import Shuffle
 register_codec(Shuffle)
 
-try:
+from numcodecs.bitround import BitRound
+register_codec(BitRound)
+
+with suppress(ImportError):
     from numcodecs.msgpacks import MsgPack
     register_codec(MsgPack)
-except ImportError: # pragma: no cover
-    pass
 
 from numcodecs.checksum32 import CRC32, Adler32
 register_codec(CRC32)
@@ -113,11 +105,9 @@ register_codec(Adler32)
 from numcodecs.json import JSON
 register_codec(JSON)
 
-try:
+with suppress(ImportError):
     from numcodecs import vlen
     from numcodecs.vlen import VLenUTF8, VLenBytes, VLenArray
     register_codec(VLenUTF8)
     register_codec(VLenBytes)
     register_codec(VLenArray)
-except ImportError:  # pragma: no cover
-    pass
